@@ -7,6 +7,7 @@ from .schedules import ScheduleAPI
 from .paging import PagingAPI
 from .huntgroup import HuntGroupAPI
 from .callqueue import CallQueueAPI
+from .autoattendant import AutoAttendantAPI
 from ..api_child import ApiChild
 from ..rest import RestSession
 
@@ -16,7 +17,8 @@ __all__ = ['TelephonyApi']
 class TelephonyApi(ApiChild, base='telephony'):
     """
     The telephony API. Child of :class:`WebexSimpleApi`
-    
+
+    :ivar auto_attendant: :class:`autoattendant.AutoAttendantAPI`
     :ivar calls: :class:`calls.CallsApi`
     :ivar schedules: :class:`schedules.ScheduleAPI`
     :ivar paging: :class:`paging.PagingAPI`
@@ -27,6 +29,7 @@ class TelephonyApi(ApiChild, base='telephony'):
 
     def __init__(self, session: RestSession):
         super().__init__(session=session)
+        self.auto_attendant = AutoAttendantAPI(session=session)
         self.calls = CallsApi(session=session)
         self.schedules = ScheduleAPI(session=session)
         self.paging = PagingAPI(session=session)
