@@ -1,14 +1,15 @@
+from collections.abc import Generator
 from enum import Enum
 from typing import List, Optional
 
 from pydantic import Field
 
 from .announcement import AnnouncementAPI
-from ..hg_and_cq import HGandCQ, AlternateNumber, Policy, Agent, RingPattern, AlternateNumberSettings, ForwardingAPI, \
-    FeatureSelector
-from collections.abc import Generator
-from ...rest import RestSession
+from ..forwarding import ForwardingAPI, FeatureSelector
+from ..hg_and_cq import HGandCQ, Policy, Agent, AlternateNumberSettings
 from ...base import to_camel, ApiModel
+from ...common import RingPattern, AlternateNumber
+from ...rest import RestSession
 
 __all__ = ['CallQueueAPI', 'CallQueue', 'CallQueueDetail',
            'AlternateNumber', 'AlternateNumberSettings', 'CallBounce', 'DistinctiveRing', 'Policy',
@@ -86,10 +87,12 @@ class OverflowAction(str, Enum):
     transfer_to_phone_number = 'TRANSFER_TO_PHONE_NUMBER'
     play_ringing_until_caller_hangs_up = 'PLAY_RINGING_UNTIL_CALLER_HANGS_UP'
 
+
 class Greeting(str, Enum):
     default = 'DEFAULT'
     custom = 'CUSTOM'
 
+
 class OverflowSetting(ApiModel):
     action: Optional[OverflowAction]
     send_to_voicemail: Optional[bool]
@@ -249,10 +252,11 @@ class CallQueueAPI:
     """
     Call Queue APÍ
 
-    :ivar forwarding: forwarding API :class:`wxc_sdk.telephony.hg_and_cq.ForwardingAPI`
+    :ivar forwarding: forwarding API :class:`wxc_sdk.telephony.forwarding.ForwardingAPI`
     :ivar announcement: announcement API :class:`announcement.AnnouncementAPI`
 
     """
+
     def __init__(self, session: RestSession):
         self._session = session
         self.forwarding = ForwardingAPI(session=session, feature_selector=FeatureSelector.queues)
@@ -299,7 +303,7 @@ class CallQueueAPI:
         :return:
         """
         return next((cq for cq in self.list(location_id=location_id, org_id=org_id, name=name)
-                     if cq.name==name), None)
+                     if cq.name == name), None)
 
     def create(self, location_id: str, queue: CallQueueDetail, org_id: str = None) -> str:
         """
